@@ -36,7 +36,7 @@ setMethod(
       col = "grey",
       las = 1
     )
-    for (i in seq_len(length(unique(types)))) {
+    for (i in seq_along(unique(types))) {
       f <- types == sort(unique(types))[i]
       syms <- append(syms, ((i - 1) %% 25) + 1)
       points(
