@@ -45,7 +45,7 @@ setMethod(
     # ======================================================================
     sampleNames <- colnames(Obj)
     orderID <- lpsorder
-    order <- seq_len(length(lpsorder))
+    order <- seq_along(lpsorder)
     orderTable <- data.frame(order, orderID)
     if (export) write.csv(orderTable, file = paste0(filename, ".csv"))
     if (!quiet) print(orderTable)
